@@ -1,16 +1,4 @@
 # Copyright 1999-2001 by Roger S. Bivand
-#
-#  This program is free software; you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation; either version 2 of the License, or
-#  (at your option) any later version.
-#
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-
 #
 #
 # rast.put moves a single numeric vector to GRASS, using the metadata
@@ -23,7 +11,7 @@ rast.put <- function(G, lname="", layer, title="", cat=FALSE, DCELL=FALSE, break
 	stop("Single new GRASS data base file name required")
     if (!(is.numeric(layer) || is.factor(layer)))
 	stop("layer is neither numeric nor factor")
-    if(is.loaded("rastput") && (interp == FALSE)) {
+    if(is.loaded("rastput", PACKAGE="grassR") && (interp == FALSE)) {
 	if(is.null(nullcol)) nullcol <- "honeydew"
 	if(is.null(defcol)) defcol <- "pale turquoise"
 	nullcolor <- as.integer(col2rgb(nullcol[1]))
@@ -41,7 +29,8 @@ rast.put <- function(G, lname="", layer, title="", cat=FALSE, DCELL=FALSE, break
 		isfactor=TRUE, DCELL=FALSE, levels=levels(layer),
 		output=lname, title=title, breaks=NULL,
 		color=as.integer(color), nullcolor=as.integer(nullcolor),
-		as.integer(defcolor), range=as.integer(layer.range))
+		as.integer(defcolor), range=as.integer(layer.range),
+		PACKAGE="grassR")
 	} else {
 	    if(is.null(breaks)) {
 		breaks <- pretty(as.double(na.omit(layer)), n=20, min.n=10)
@@ -64,7 +53,7 @@ rast.put <- function(G, lname="", layer, title="", cat=FALSE, DCELL=FALSE, break
 		DCELL=FALSE, levels=layer.levels, output=lname, title=title,
 		breaks=as.double(breaks), color=as.integer(col),
 		nullcolor=as.integer(nullcolor), as.integer(defcolor),
-		range=as.double(layer.range))
+		range=as.double(layer.range), PACKAGE="grassR")
 	}
     } else {
 	G.list <- list.GRASS(type="rast")
@@ -80,10 +69,10 @@ rast.put <- function(G, lname="", layer, title="", cat=FALSE, DCELL=FALSE, break
 		"\ncols:    ", G$Ncol, "\n", sep="")
 	cat(outstr, file=FILE)
 	if (cat) write(t(matrix(as.integer(codes(layer)), nrow=G$Nrow,
-		ncol=G$Ncol, byrow=T)), file=FILE, append=T,
+		ncol=G$Ncol, byrow=TRUE)), file=FILE, append=TRUE,
 		ncolumns=G$Ncol)
 	else write(t(matrix(as.double(layer), nrow=G$Nrow, ncol=G$Ncol, 
-		byrow=T)), file=FILE, append=T, ncolumns=G$Ncol)
+		byrow=TRUE)), file=FILE, append=TRUE, ncolumns=G$Ncol)
 	if (cat) system(paste("r.in.ascii -i input=", FILE, " nv=NA output=", 
 		lname, " title=\"", title, "\"", sep=""))
 	else {
